import { Controller } from '@hotwired/stimulus';

export default class extends Controller {
  connect() {
    this.magicType = this.element.getAttribute('data-magic-type');
  }

  applyMagic(_e) {
    switch (this.magicType) {
      case 'fill-input-value':
        this._fillInputValue();
        break;
      case 'set-slimselect-selections':
        this._setSlimSelectSelections();
        break;
    }

    this.element.classList.add('hidden');
  }

  _fillInputValue() {
    const targetId = this._magicWandTargetId;
    const inputValue = this._magicWandPayload;
    const target = document.querySelector(`input[id="${targetId}"],textarea[id="${targetId}"]`);

    target.value = inputValue;
  }

  _setSlimSelectSelections() {
    const targetId = this._magicWandTargetId;
    const selections = JSON.parse(this._magicWandPayload);
    const target = document.querySelector(`select[id="${targetId}"]`);

    target.slimSelect.setSelected(selections);
  }

  get _magicWandTargetId() {
    return this.element.getAttribute('data-magic-target').replace('#', '');
  }

  get _magicWandPayload() {
    return this.element.getAttribute('data-magic-payload');
  }
}