import { Controller } from '@hotwired/stimulus';

export default class extends Controller {
  static targets = ['dialog', 'form', 'input', 'scrollContainer', 'messages'];

  connect() {
    this.dialogTarget.showModal();
    this.scrollToBottom();
    this.inputTarget.focus();
    this.observeMessages();
  }

  disconnect() {
    if (this._turboSubmitEndHandler) {
      this.formTarget.removeEventListener('turbo:submit-end', this._turboSubmitEndHandler);
      this._turboSubmitEndHandler = null;
    }

    this.messagesObserver.disconnect();
    this.messagesObserver = null;
  }

  handleSubmit(event) {
    if (!this.hasInputTarget || !this.hasFormTarget) return;
    const currentValue = this.inputTarget.value;
    if (!currentValue.trim()) {
      event.preventDefault();
      return;
    }

    this.inputTarget.disabled = true;

    const turboSubmitEndHandler = () => {
      this.inputTarget.disabled = false;
      this.inputTarget.focus();
      this.inputTarget.value = '';
    };

    this.formTarget.addEventListener('turbo:submit-end', turboSubmitEndHandler, { once: true });
    this._turboSubmitEndHandler = turboSubmitEndHandler;
  }

  hideDialog() {
    this.dialogTarget.close();
  }

  scrollToBottom(smooth = false) {
    if (!this.hasScrollContainerTarget) return;

    this.scrollContainerTarget.scrollTo({
      top: this.scrollContainerTarget.scrollHeight,
      behavior: smooth ? 'smooth' : 'auto',
    });
  }

  backdropClick(event) {
    if (event.target === this.dialogTarget) {
      this.hideDialog();
    }
  }

  observeMessages() {
    this.messagesObserver = new MutationObserver(() => {
      setTimeout(() => this.scrollToBottom(true), 100);
    });

    this.messagesObserver.observe(this.messagesTarget, {
      childList: true,
      subtree: true,
    });
  }
}
