// annotation_service.js

export class AnnotationService {
  constructor(documentId) {
    this.documentId = documentId;
    this.csrfToken = document.querySelector('meta[name="csrf-token"]')?.content;
  }

  async fetchAnnotations() {
    try {
      const response = await fetch(`/spirit_hub/documents/${this.documentId}/pdf_annotations`);
      if (!response.ok) throw new Error(`Failed to load annotations: ${response.status}`);
      const json = await response.json();
      return json.data;
    } catch (error) {
      console.error('Error loading annotations:', error);
      throw error;
    }
  }

  async saveAnnotation(id, annotationData, isNew = true) {
    const url = isNew ? `/spirit_hub/documents/${this.documentId}/pdf_annotations` : `/spirit_hub/documents/${this.documentId}/pdf_annotations/${id}`;
    const method = isNew ? 'POST' : 'PATCH';

    try {
      const response = await fetch(url, {
        method,
        headers: {
          'Content-Type': 'application/json',
          'X-CSRF-Token': this.csrfToken,
        },
        body: JSON.stringify(annotationData),
      });

      if (!response.ok) throw new Error(`Failed to save annotation: ${response.status}`);
      return await response.json();
    } catch (error) {
      console.error('Error saving annotation:', error);
      throw error;
    }
  }

  async deleteAnnotation(id) {
    if (id.includes('-')) return true;

    try {
      const response = await fetch(`/spirit_hub/documents/${this.documentId}/pdf_annotations/${id}`, {
        method: 'DELETE',
        headers: {
          'X-CSRF-Token': this.csrfToken,
        },
      });

      if (!response.ok) throw new Error(`Failed to delete annotation: ${response.status}`);
      return true;
    } catch (error) {
      console.error('Error deleting annotation:', error);
      throw error;
    }
  }
}
