export async function renderThumbnails(thumbnail_action = null) {
  for (let i = 0; i < this.totalPagesValue; i++) {
    const pageNum = i + 1;
    const thumbnailDiv = createThumbnail.call(this, pageNum, thumbnail_action);
    const canvas = thumbnailDiv.querySelector('canvas');

    const page = await this.pdf.getPage(pageNum);
    const viewport = page.getViewport({
      scale: this.constructor.THUMBNAIL_SIZE / page.getViewport({ scale: 1.0 }).width,
    });

    canvas.width = viewport.width;
    canvas.height = viewport.height;

    const context = canvas.getContext('2d');
    await page.render({
      canvasContext: context,
      viewport: viewport,
    }).promise;
  }
}

export function createThumbnail(pageNumber, thumbnail_action) {
  const div = document.createElement('div');
  div.dataset.page = pageNumber;
  let classes = 'thumbnail border rounded-md';

  if (thumbnail_action) {
    classes += ' hover:border-gray-300 cursor-pointer';
    div.dataset.action = thumbnail_action;
  }

  div.className = classes;

  const canvas = document.createElement('canvas');
  canvas.className = `w-[${this.constructor.THUMBNAIL_SIZE}px] h-auto rounded-t-md`;

  const textDiv = document.createElement('div');
  textDiv.className = 'text-center text-xs mt-1 p-2';
  textDiv.textContent = `Page ${pageNumber}`;

  div.appendChild(canvas);
  div.appendChild(textDiv);

  this.thumbnailContainerTarget.appendChild(div);
  return div;
}
