# frozen_string_literal: true

module ActionButtons
  class GroupedSendActionsComponent < BaseComponent
    attr_reader :tagset, :user, :options, :use_directory_delete

    def initialize(tagset:, user:, options: {})
      super
      @tagset = tagset
      @user = user
      @possible_next_states_without_share = SpiritHub::HubdocCycle.possible_next_states(tagset).reject { |state| state.key.to_sym == :share }
      @use_directory_delete = options.fetch(:use_directory_delete, false)
      @options = options

      @doc = @tagset.doc.presence
    end

    def send_states
      @possible_next_states_without_share.select { |state| state.key.to_s.start_with?('to_') }
    end

    def other_states
      @possible_next_states_without_share.reject { |state| state.key.to_s.start_with?('to_') }
    end

    def versioned_tagset?
      @tagset.one_doc? && @tagset.doc.versions_count.positive?
    end
  end
end
