# frozen_string_literal: true

module ActionButtons
  class StateButtonComponent < BaseButtonComponent
    attr_reader :model, :state, :state_key, :disabled, :user, :with_color

    def initialize(model:, user:, state:, with_color: false, show_text: false)
      super(show_text:)
      @model = model
      @state = state
      @user = user
      @state_key = state.key.to_sym
      @with_color = with_color
      @disabled = state_key == :generate_linked_document # TODO: Remove this line when we have a proper implementation for this state
    end

    def title
      state.title
    end

    def icon
      "fa #{state.form_icon}"
    end

    def button_classes
      return super unless with_color

      additional_classes = 'rounded-lg font-semibold'

      color_classes = case state_key
                      when :validate
                        'text-white bg-[#12B76A] hover:bg-[#95D475]'
                      when :refuse
                        'text-white bg-spirit-brigthred hover:bg-[#F38588]'
                      end

      "#{DEFAULT_CLASSES[:button]} #{button_size_classes} #{color_classes} #{additional_classes}".strip
    end

    def icon_classes
      return super unless with_color

      "#{DEFAULT_CLASSES[:icon]} text-white".strip
    end

    def confirm_message
      return unless state_key == :done

      'Êtes-vous sûr de vouloir passer ce document en traité ?'
    end

    def render?
      SpiritHub::HubdocCycle.can_change_to_state?(model, state_key, user)
    end
  end
end
