# frozen_string_literal: true

class ChatbotModalComponent < BaseComponent
  attr_reader :user, :channel

  def initialize(user, channel = nil)
    @user       = user
    @channel    = channel || Channel.new(responsible: user)

    super
  end

  def current_bot
    Bot.hubgpt!
  end

  def today_channels
    Channel.user_channels(user).today_not_favorite(user)
  end

  def yesterday_channels
    Channel.user_channels(user).yesterday_not_favorite(user)
  end

  def last_week_channels
    Channel.user_channels(user).last_week_not_favorite(user)
  end

  def last_month_channels
    Channel.user_channels(user).last_month_not_favorite_not_last_week(user)
  end

  def favorite_channels
    user.favorite_channels
  end

  def instant_messages
    return [] if channel.blank?

    channel.instant_messages
  end

  def model
    channel
  end

  def url
    channel.persisted? ? spirit_hub_channel_path(channel) : spirit_hub_channels_path
  end

  def form_with_options
    {
      model:,
      remote: true,
      url:,
      data: {
        chatbot_modal_target: 'form'
      },
      class: 'relative'
    }
  end
end
