# frozen_string_literal: true

module Comment
  class ItemComponent < BaseComponent
    attr_reader :comment, :nested

    def initialize(comment)
      @comment = comment
      super()
    end

    def full_name
      comment&.user&.first_name || comment.full_name || 'Author'
    end

    def replies
      return [] unless comment.root_comment?

      comment.channel.instant_messages.where(parent_message_id: comment.id)
    end

    def parent_message_id
      comment.parent_message_id.presence || comment.id
    end

    private

    def wrapper_classes
      'flex flex-col p-4 rounded-lg bg-white shadow-sm'
    end
  end
end
