# frozen_string_literal: true

module Comment
  class ModalComponent < ::BaseComponent
    attr_reader :user, :channel, :commentable

    def initialize(user, commentable)
      @user = user
      @commentable = commentable
      @channel = commentable.comment_channel || Channel.new(
        responsible: user,
        name: "Comments for #{commentable.title}",
        key: "#{commentable.class.name.underscore}_comments_#{commentable.id}",
        writers: commentable.writers,
        members: commentable.writers
      )
      super
    end

    def channel_key
      channel.key
    end

    def comments
      return [] unless channel.persisted?

      channel.instant_messages.where(type: InstantMessage::TYPES[:comment]).asc(:created_at)
    end

    def root_comments
      comments.where(parent_message_id: nil)
    end

    def replies_for(comment)
      comments.where(parent_message_id: comment.id)
    end

    def can_reply_to?(comment)
      comment.root_comment? && comment.last_comment? && !comment.reply?
    end

    def url
      spirit_hub_channels_path
    end

    private

    def form_with_options
      {
        model: InstantMessage.new,
        url:,
        data: {
          controller: 'comments',
          action: 'turbo:submit-end->comments#reset'
        },
        class: 'relative'
      }
    end
  end
end
