# frozen_string_literal: true

module InstantMessages
  class ItemComponent < BaseComponent
    attr_reader :instant_message, :documents

    def initialize(instant_message)
      @instant_message  = instant_message
      @documents        = Doc.where(_id: { :$in => instant_message.channel.doc_ids })

      super
    end

    def user?
      !assistant?
    end

    def assistant?
      instant_message.llm_r.present?
    end

    def markdown(text)
      options = {
        filter_html: true,
        hard_wrap: true,
        link_attributes: { rel: 'nofollow' },
        space_after_headers: true,
        fenced_code_blocks: true
      }
      extensions = {
        autolink: true,
        superscript: true,
        disable_indented_code_blocks: true
      }

      renderer = ::Redcarpet::Render::HTML.new(options)
      markdown = ::Redcarpet::Markdown.new(renderer, extensions)
      markdown.render(text).html_safe
    end
  end
end
