# frozen_string_literal: true

module Tagsets
  class ShareFromInfoModalComponent < BaseComponent
    include SpiritHub::ActorFormatterHelper

    attr_reader :tagset

    def initialize(tagset:)
      super
      @tagset = tagset
    end

    def title
      if tagset.one_doc?
        'Partager à partir des informations du document'
      elsif tagset.multiple_doc?
        'Partager à partir des informations des documents'
      end
    end

    def recipients_dropdown_data
      data = {}

      tagset.docs.each do |doc|
        preselections, new_contacts = recipients_dropdown_preselections_for(doc)
        options = recipients_dropdown_options_for(doc, preselections, new_contacts)

        data[doc.id.to_s] = { options:, preselections: }
      end

      data
    end

    private

    def recipients_dropdown_preselections_for(doc)
      preselections = []

      if doc.extracted_emails.present?
        users = User.with_emails(doc.extracted_emails)
        contacts = Doc.contacts_with_emails(doc.extracted_emails - users.pluck(:email))
        new_contacts = doc.extracted_emails - users.map(&:email) - contacts.map(&:email)

        preselections += users.map { |u| SpiritHub::ActorFormatter::UserActor.new(u).id_value }
        preselections += contacts.map { |c| SpiritHub::ActorFormatter::DocActor.new(c).id_value }
        preselections += new_contacts
      end

      [preselections, new_contacts]
    end

    def recipients_dropdown_options_for(doc, preselections, new_contacts)
      if doc.extracted_emails.present?
        actors_for_select('users', 'groups', 'contacts', preselections:) + new_contacts.map { |email_address| [email_address, email_address] }
      else
        actors_for_select('users', 'groups', 'contacts')
      end
    end
  end
end
