# frozen_string_literal: true

# Tables with subsections
module Sectionable
  extend ActiveSupport::Concern

  def setup_definitions(collections)
    collections.each do |collection|
      scope = instance_variable_get("@all_#{collection}")
      per_page = params.fetch("#{collection}_per_page", self.class::PER_PAGE).to_i

      collection_per_page = instance_variable_set("@#{collection}_per_page", per_page)
      models = instance_variable_set("@#{collection}", sorted_models(scope, default_sort_by: 'cleaned_main_key'))

      if @view_type == 'table'
        limited_scope = models.take(collection_per_page)
        models = instance_variable_set("@#{collection}", limited_scope)
      end

      instance_variable_set("@#{collection}_count", models.count)
      instance_variable_set("@total_#{collection}_count", scope.count)
    end
  end

  private

  def sorted_models(scope, options = {})
    @sort_by = params.fetch(:sort_by, options[:default_sort_by]).to_s
    @sort_direction = params.fetch(:sort_direction, 'asc').to_s

    if scope.fields.keys.include?(@sort_by) # rubocop:disable Style/ConditionalAssignment
      # Ordering using mongo query if the column is a DB attribute
      models = scope.order_by(@sort_by => @sort_direction)
    else
      # Sorting on computed counter from tagset_docs methods
      models = scope.to_a.sort_by do |m|
        # Fix brakeman 'Dangerous Send' complaining
        safe_sorter = self.class::SAFE_SORTERS.find { |sorter| sorter == @sort_by }
        next unless safe_sorter

        @sort_direction == 'asc' ? -m.send(safe_sorter).count : m.send(safe_sorter).count
      end
    end

    set_columns
    set_view_type

    models.to_a
  end
end
