# frozen_string_literal: true

module SpiritHub
  class CommentsController < ApplicationController
    skip_before_action :authenticate_user!
    before_action :skip_authorization, :skip_policy_scope

    def new
      interactor = Comments::Build.call(params, current_user)

      if interactor.success?
        render turbo_stream: [
          turbo_stream.update(:modal, Comment::NewModalComponent.new(current_user, interactor.result))
        ]
      else
        flash_error(interactor)
      end
    end

    def create
      interactor = Comments::Create.call(params, current_user)

      if interactor.success?
        flash.now[:notice] = 'Comment added successfully'
        render turbo_stream: [
          turbo_stream.update('modal', '')
        ]
      else
        flash_error(interactor)
      end
    end

    private

    def flash_error(interactor)
      flash.now[:alert] = interactor.errors.full_messages.join(', ')
      render turbo_stream: [
        turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
      ]
    end
  end
end
