# frozen_string_literal: true

module SpiritHub
  class ErrorsController < ApplicationController
    skip_before_action :authenticate_user!
    before_action :skip_authorization, :skip_policy_scope

    def generate_error
      @user = current_user
      code = params[:code].to_i

      return render 'spirit_hub/errors/generate_error', status: :ok if code.zero?

      case code
      when 404
        not_found
      when 403
        raise Pundit::NotAuthorizedError
      when 500
        raise StandardError, 'This is a test error'
      else
        render_error_500
      end
    end

    def not_found
      respond_with_error(
        error_message: 'Cette page n\'a pas été trouvée',
        error_status: :not_found
      )
    end
  end
end
