# frozen_string_literal: true

module SpiritHub
  class PdfAnnotationsController < ApplicationController
    before_action :set_document
    after_action :skip_policy_scope, :skip_authorization

    def index
      @annotations = @document.pdf_annotations
      render json: { data: @annotations.map(&:to_frontend_json) }
    end

    def create
      @annotation = @document.pdf_annotations.build(annotation_params)

      if @annotation.save
        render json: @annotation.to_frontend_json, status: :created
      else
        render json: { errors: @annotation.errors.full_messages }, status: :unprocessable_entity
      end
    end

    def update
      @annotation = @document.pdf_annotations.find(params[:id])

      if @annotation.update(annotation_params)
        render json: @annotation.to_frontend_json
      else
        render json: { errors: @annotation.errors.full_messages }, status: :unprocessable_entity
      end
    end

    def destroy
      @annotation = @document.pdf_annotations.find(params[:id])
      @annotation.destroy

      head :no_content
    end

    private

    def set_document
      @document = Doc.find(params[:document_id])
    end

    def annotation_params
      # Remove annotation_id since we're using Mongoid's _id
      params.require(:annotation).permit(
        :page_index,
        :content,
        position_data: {},
        style_data: {}
      ).merge(type: 'SpiritHub::Pdf::Annotation::Text')
    end
  end
end
