# frozen_string_literal: true

module SpiritHub
  module Shares
    class DownloadsController < ApplicationController
      skip_before_action :authenticate_user!
      before_action :skip_authorization, :skip_policy_scope
      before_action :check_for_virus

      def download_doc
        render body: nil and return unless document

        if (file = document.file)
          mode = params[:mode] || 'inline'
          send_doc_file(document, file, mode)
        else
          flash[:notice] = t('flash.notice.doc_file_missing')
          redirect_back(fallback_location: spirit_hub_upload_url(upload.id))
        end
      end

      def download_all_docs
        documents = upload.documents.all
        zip_name = "Docs #{upload.id}.zip"

        if documents.count.positive?
          send_files_as_zip(documents, zip_name)
        else
          render body: nil
        end
      end

      private

      def check_for_virus
        documents = [document] if params[:doc_id].present?
        documents ||= upload.documents.all

        documents.each do |doc|
          if doc.has_virus?
            flash[:notice] = t('flash.alert.doc_has_virus')
            redirect_back(fallback_location: spirit_hub_upload_url(upload.id)) and break
          end

          if doc.needs_to_be_scanned?
            flash[:notice] = t('flash.alert.doc_not_scanned')
            redirect_back(fallback_location: spirit_hub_upload_url(upload.id)) and break
          end
        end
      end

      def document
        @document ||= upload.documents.find(params[:doc_id])
      end

      def upload
        @upload ||= Upload.find(params[:upload_id])
      end
    end
  end
end
