# frozen_string_literal: true

module SpiritHub
  module TeamActivities
    class CollaboratorController < ApplicationController
      before_action :set_collaborator
      before_action :find_models, only: %i[index sort]
      before_action :skip_policy_scope

      include Datatablable
      include Sectionable

      PER_PAGE = 10

      def index
        authorize(Tagset, policy_class:)

        respond_to(&:html)
      end

      def sort
        authorize(Tagset, policy_class:)

        render partial: 'spirit_hub/team_activities/collaborator/table'
      end

      private

      def table_partial
        'spirit_hub/team_activities/collaborator/table'
      end

      def set_collaborator
        @collaborator = User.find(params[:collaborator_id])
      end

      def find_models
        @all_to_be_signed = @collaborator.to_be_signed_docs
        @all_to_complete = @collaborator.to_complete_docs
        @all_to_validate = @collaborator.to_validate_docs
        @all_responses = @collaborator.responses_docs
        setup_definitions(%i[to_be_signed to_complete to_validate responses])

        set_user_favorite_tagset_ids
      end
    end
  end
end
