# frozen_string_literal: true

module SpiritHub
  class BaseInteractor
    extend ActiveModel::Naming

    def self.call(params, current_user, ...)
      new(params, current_user, ...).call
    end

    attr_accessor :base
    attr_reader :params, :current_user, :errors, :result

    def initialize(params, current_user, ...)
      @params       = params
      @current_user = current_user
      @errors       = ActiveModel::Errors.new(self)
      @result       = nil
    end

    def call
      yield if block_given?
      self
    rescue StandardError => e
      errors.add(:base, e.message)
      raise e if Rails.env.development?

      self
    end

    def success?
      errors.empty?
    end

    def failure?
      !success?
    end

    def source
      params[:source] || :paw
    end

    def read_attribute_for_validation(attr)
      send(attr)
    end

    def self.human_attribute_name(attr, _options = {})
      attr
    end

    def self.lookup_ancestors
      [self]
    end
  end
end
