# frozen_string_literal: true

module SpiritHub
  module Channels
    class Build < Base
      attr_reader :session

      def initialize(params, user, session)
        super
        @session = session
      end

      def call
        super do
          build_channel
          add_tagset_context_message
          yield(@result) if block_given?
          @result
        end
      end

      private

      def description
        results = session[:spirit_hub_context_results].dup
        results = [] if results.nil?

        results.map! do |result|
          result.map do |key, tagset_ids|
            {
              key => tagset_ids.filter_map do |tagset_id|
                tagset = ::Tagset.find(tagset_id)
                next if tagset.nil?

                {
                  tagset_id:,
                  docs: tagset.find_docs_or_children_docs.map do |doc|
                    {
                      doc_id: doc.id,
                      title: doc.title
                    }
                  end,
                  title: tagset.title,
                  type: tagset.type
                }
              end
            }
          end
        end

        Langchain::Prompt::PromptTemplate.new(
          input_variables: ['context'],
          template: File.read(SpiritHub::Engine.root.join('app/interactors/spirit_hub/channels/build.md'))
        ).format(context: results)
      end

      def build_channel
        @result = Channel.new(
          name: "#{MAIN_BOT_NAME} et du #{Time.zone.now.strftime('%d/%m/%Y %H:%M')}",
          description:
        )
        @result.readers = [bot_id]
        @result.responsible = current_user.id

        @result
      end

      def add_tagset_context_message
        return if channel_params[:tagset_id].blank?

        tagset = ::Tagset.find(channel_params[:tagset_id])
        @result.tagset_id = tagset.id.to_s
        @result.instant_messages.build(
          text: "Comment puis-je vous aider avec #{tagset.title} ?",
          user: Bot.find(bot_id),
          llm_role: :assistant
        )
      end
    end
  end
end
