# frozen_string_literal: true

module SpiritHub
  module Comments
    class Base < BaseInteractor
      private

      def comment_params
        params.require(:instant_message).permit(:text, :full_name, :parent_message_id, :channel_key)
              .except(:channel_key)
              .merge(user_id: current_user&.id, type: InstantMessage::TYPES[:comment])
      end

      def find_or_create_comment_channel
        @find_or_create_comment_channel ||= Channel.find_by(key: params[:instant_message][:channel_key])
        @find_or_create_comment_channel ||= create_comment_channel
      end

      def commentable
        return @commentable if @commentable

        commentable_type, commentable_id = params[:instant_message][:channel_key].split('_comments_')
        @commentable = commentable_type.classify.constantize.find(commentable_id)
      end

      def create_comment_channel
        Channel.create!(
          responsible: current_user&.id,
          name: "Comments for #{commentable.title}",
          key: "#{commentable.class.name.underscore}_comments_#{commentable.id}",
          commentable:,
          writers: commentable.writers,
          members: commentable.writers
        )
      end
    end
  end
end
