# frozen_string_literal: true

module SpiritHub
  module Docs
    class EmailsExtracterJob < ApplicationJob
      # NOTE: Taken from URI::MailTo::EMAIL_REGEXP, but without the \A\z delimiters.
      EMAIL_REGEXP = %r{[a-zA-Z0-9.!\#$%&'*+/=?^_`{|}~-]+@[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?(?:\.[a-zA-Z0-9](?:[a-zA-Z0-9-]{0,61}[a-zA-Z0-9])?)*}

      def perform(doc_id)
        doc = Doc.find(doc_id)

        # NOTE: For now, we're only extracting email addresses from PDF docs.
        return unless doc&.pdf?

        doc.update!(
          extracted_emails: extract_email_addresses_from(doc),
          extracted_emails_at: Time.current
        )
      end

      private

      def extract_email_addresses_from(doc)
        doc.text
           .scan(EMAIL_REGEXP)
           .select { |email_addr| EmailAddress.valid?(email_addr) }
           .map { |email_addr| EmailAddress.normal(email_addr) }
      end
    end
  end
end
