# frozen_string_literal: true

module SpiritHub
  class TagsetsMailer < SpiritHub::ApplicationMailer
    # rubocop:disable Metrics/ParameterLists
    def share(upload:, subject:, message:, to:, cc: nil, bcc: nil)
      upload = Upload.find_by!(id: upload) unless upload.is_a?(Upload)

      @user = upload.user
      @message = message
      # NOTE: Temporary, since we'll change this link soon.
      # For some reason routes from core are not visible here, so I'm constructing it manually.
      @share_link = spirit_hub_upload_url(upload.id)

      from = @user&.email_with_name.presence || APP_CONFIG['smtp_no_reply']

      mail(
        from:,
        return_path: from,
        to:,
        cc:,
        bcc:,
        subject:
      )
    end
    # rubocop:enable Metrics/ParameterLists

    def document_uploaded(tagset_id:, uploader_user_id:, emails:)
      @tagset = Tagset.find(tagset_id)
      raise ArgumentError, "Tagset with id #{tagset_id} is not a document" unless @tagset.doc?

      @uploader = User.find(uploader_user_id).full_name
      @directory = @tagset.parent&.title || 'sans nom'
      @operation = @tagset.operation&.title || 'sans nom'
      @main_object_name = SpiritHub::Setting.main_object_name.downcase
      @title = @tagset.title || 'sans titre'
      @date = @tagset.created_at.strftime('%d/%m/%Y à %H:%M')

      mail(
        to: emails,
        subject: "Un nouveau document (#{@title}) a été déposé dans le dossier #{@directory}"
      )
    end
  end
end
