# frozen_string_literal: true

module SpiritHub
  class Completeness < ApplicationRecord
    field :title, type: String
    field :completed, type: Mongoid::Boolean, default: false
    field :min_objects, type: Integer, default: 1
    field :object_ids, type: Array, default: []
    field :superfields, type: Hash, default: {}

    belongs_to :tagset, index: true
    before_save :udpate_completed

    after_save :after_save_update_tagset_completeness
    after_destroy :after_destroy_update_tagset_completeness

    private

    def udpate_completed
      return unless object_ids_changed? || min_objects_changed?

      self.completed = object_ids.to_a.length >= min_objects
    end

    def after_save_update_tagset_completeness
      return unless %i[object_ids min_objects tagset_id].any? { |attr| saved_change_to_attribute?(attr) }

      update_tagset_completeness(tagset) if tagset

      previous_tagset = Tagset.find_by(id: previous_changes['tagset_id']&.first)
      update_tagset_completeness(previous_tagset) if previous_tagset && previous_tagset.id.to_s != tagset_id.to_s
    end

    def after_destroy_update_tagset_completeness
      update_tagset_completeness(tagset) if tagset
    end

    def update_tagset_completeness(tagset)
      DirectoryCompletenessUpdater.call(tagset)
    end
  end
end
