# frozen_string_literal: true

module SpiritHub
  module LLM
    module Tools
      class WorkflowTool < ::LLM::Tools::WorkflowTool
        slug :spirit_hub_workflow_tool

        define_function(
          :get_dashboard_docs,
          description: 'WorkflowTool: Get list of docs for one category, to_process_docs are all docs ' \
            'where the user has an action, to_fill_docs are all docs that are not yet in ' \
            'any space, to_sign_docs are docs to sign. to_view_docs are the doc that ' \
            'someone ask me to read'
        ) do
          property(
            :category,
            type: 'string',
            description: 'key of the category, could be one of those values : ' \
              'to_classify or to_be_processed',
            required: false
          )
        end

        def get_dashboard_docs(category: nil)
          raise 'user missing' if user.nil?

          results = {}
          if category.nil? || category == 'to_classify'
            search = SpiritHub::Search::SpacesSearch.new(Tagset.to_classify.selector, { user: })
            results['to_classify'] = search.json_serialized_array

          end
          if category.nil? || category == 'to_be_processed'
            search = SpiritHub::Search::SpacesSearch.new(Tagset.to_be_processed(user).selector, { unscoped: true })
            results['to_be_processed'] = search.json_serialized_array
          end
          Rails.logger.tagged('[TOOL]').debug results
          results.to_json
        end
      end
    end
  end
end
