# frozen_string_literal: true

module SpiritHub
  module Pdf
    module Annotation
      class Base < ApplicationRecord
        include Mongoid::Document
        include Mongoid::Timestamps

        store_in collection: 'pdf_annotations'

        field :type, type: String
        field :page_index, type: Integer
        field :content, type: String
        field :position_data, type: Hash, default: {}
        field :style_data, type: Hash, default: {}

        belongs_to :doc, index: true

        validates :page_index, presence: true

        # Convert to the format expected by the frontend
        def to_frontend_json
          {
            id: id.to_s, # Convert BSON::ObjectId to string
            pageIndex: page_index,
            rect: position_data['rect'],
            value: content,
            annotationType: annotation_type
          }
        end

        # This should be overridden by subclasses
        def annotation_type
          raise NotImplementedError
        end
      end
    end
  end
end
