# frozen_string_literal: true

module SpiritHub
  class Phase < ApplicationRecord
    field :title, type: String
    field :initial_date, type: Date
    field :postponed_date, type: Date
    field :actual_date, type: Date
    field :percentage, type: Integer, default: 0

    belongs_to :operation, index: true, class_name: 'SpiritHub::Operation'
    belongs_to :parent, foreign_key: :parent_id, optional: true, class_name: 'SpiritHub::Phase'

    index({ title: 1 }, { background: true })

    after_save :update_directories_phase_title

    def update_percentage
      self.percentage = calculate_percentage
      save
    end

    private

    def directories
      Tagset.where(phase_id: id, type: 'directory')
    end

    def update_directories_phase_title
      return unless saved_change_to_attribute?(:title)

      directories.each do |tagset|
        tagset.update(phase_title: title)
      end
    end

    def calculate_percentage
      directory_ids = directories.pluck(:id)
      return 0 if directory_ids.empty?

      total_nb = SpiritHub::Completeness.where(:tagset_id.in => directory_ids).count
      return 0 if total_nb.zero?

      completed_nb = SpiritHub::Completeness.where(:tagset_id.in => directory_ids, completed: true).count

      (100 * completed_nb.to_f / total_nb).to_i
    end
  end
end
