# frozen_string_literal: true

module SpiritHub
  class Setting
    delegate :id, :save, :update, to: :@settings

    def self.where(*args)
      ::Setting.where(*args)
    end

    def self.main_object_name
      cached_value(:object_name)
    end

    def self.cache_key(key)
      "spirit_hub:setting:#{key}"
    end

    def self.cached_value(key)
      Rails.cache.fetch(cache_key(key)) do
        instance = new
        instance.respond_to?(key) ? instance.public_send(key) : instance[key]
      end
    end

    def self.clear_cache!
      Rails.cache.delete_matched(cache_key('*'))
    end

    def initialize
      @settings = ::Setting.get_settings_for(:spirit_hub)
    end

    def [](key)
      @settings.values[key]
    end

    def []=(key, value)
      @settings.values[key] = value
    end

    def object_name
      @settings.values[:object_name] ||= 'Projet'
    end

    def object_name=(value)
      @settings.values[:object_name] = value
    end

    def model_name
      self.class
    end

    def self.param_key
      :spirit_hub_setting
    end
  end
end
