# frozen_string_literal: true

MAIN_BOT_NAME = 'HubGPT'

Bot.class_eval do # rubocop:disable Metrics/BlockLength
  def self.hubgpt
    Bot.find_by(first_name: MAIN_BOT_NAME)
  end

  def self.hubgpt!
    hubgpt || raise('Bot hubgpt not found')
  end

  def self.create_tools
    unless LLM::Tool.find_by(slug: 'spirit_hub_docs_tool')

      LLM::Tool.create!({
                          slug: 'spirit_hub_docs_tool',
                          public_read: true,
                          name: 'SpiritHubDocsTool',
                          tool_class: 'SpiritHub::LLM::Tools::DocsTool',
                          feedback_message: 'Using hupgpt docs_tool ...'
                        })
    end

    unless LLM::Tool.find_by(slug: 'spirit_hub_operations_tool')
      LLM::Tool.create!({
                          slug: 'spirit_hub_operations_tool',
                          public_read: true,
                          name: 'SpiritHubOperationsTool',
                          tool_class: 'SpiritHub::LLM::Tools::OperationsTool',
                          feedback_message: 'Using hupgpt operations_tool ...'
                        })
    end

    return if LLM::Tool.find_by(slug: 'spirit_hub_workflow_tool')

    LLM::Tool.create!({
                        slug: 'spirit_hub_workflow_tool',
                        public_read: true,
                        name: 'SpiritHubWorkflowTool',
                        tool_class: 'SpiritHub::LLM::Tools::WorkflowTool',
                        feedback_message: 'Using hupgpt workflow_tool ...'
                      })
  end

  def self.create_hubgpt!(creator:)
    create_tools

    Bot.create!(
      created_by: creator,
      first_name: MAIN_BOT_NAME,
      llm_provider: LLM::Provider.default_provider,
      public_read: true,
      email: "#{MAIN_BOT_NAME}@paw.io",
      tool_slugs: %w[
        automations_tool
        channels_tool
        spaces_tool
        spirit_hub_docs_tool
        spirit_hub_operations_tool
        spirit_hub_workflow_tool
      ],
      instructions: <<~INSTRUCTIONS
        Tu es HubGPT, un agent qui permet aux utilisateurs de travailler efficacement sur#{' '}
        leurs documents.

        Tu as accès à des outils pour exécuter les tâches demandées. Si ce n'est pas le cas,#{' '}
        tu expliques que tu n'as pas la compétence requise.

        Tu es efficace, tu t'adresses aux utilisateurs de façon précise, concise et#{' '}
        professionnelle.

        Tu travailles essentiellement avec 3 types d'objets :
        1. Des documents (modèle Tagset avec l'attribut type=documents) qui permettent de#{' '}
           stocker les fichiers (modèle Doc) via l'attribut doc_id
        2. Des espaces de type folder qui représentent les dossiers comme dans une#{' '}
           arborescence classique, avec l'attribut parent_ids qui permet de définir dans#{' '}
           quel dossier parent ils sont via des id bson
        3. Des projets qui permettent de définir une arborescence métier via des modèles#{' '}
           de plan de classement (fournis par l'utilisateur à la création sous forme de#{' '}
           fichier excel)

        Les projets contiennent des dossiers et des documents. Sur certains dossiers, on#{' '}
        aura une notion de complétude permettant de savoir si des documents sont attendus#{' '}
        dans le dossier en question.

        Les projets permettent aussi de définir des tâches à réaliser et éventuellement#{' '}
        des sous-tâches.
      INSTRUCTIONS
    )
  end

  def self.create_hubgpt_if_missing
    return hubgpt if hubgpt.present?

    admin = User.order_by(created_at: :asc).first

    create_hubgpt!(creator: admin) if admin
  end
end
