# frozen_string_literal: true

InstantMessage.prepend(Turbo::Broadcastable)

InstantMessage.class_eval do # rubocop:disable Metrics/BlockLength
  field :is_initial, type: Mongoid::Boolean, default: false
  field :automation_ids, type: Array, default: []
  field :parent_message_id, type: String
  field :full_name, type: String

  after_create :broadcast_append_to_channel, :update_waiting_for_bot

  scope :comments, -> { where(type: InstantMessage::TYPES[:comment]) }
  scope :root_comments, -> { comments.where(parent_message_id: nil) }
  scope :replies, -> { comments.where(:parent_message_id.ne => nil) }

  delegate :commentable, to: :channel
  def update_waiting_for_bot
    channel.update(waiting_for_bot: false)
  end

  def broadcast_append_to_channel
    if type == 'm'
      # Broadcast du message normal et nettoyage du message système
      broadcast_append_to_messages
      broadcast_system_message_clear
    elsif type == 'c'
      broadcast_append_to_comments
    else
      # Broadcast du message système
      broadcast_replace_system_message
    end
  end

  def user?
    !assistant?
  end

  def assistant?
    user.is_a?(Bot)
  end

  def reply?
    parent_message_id.present?
  end

  def root_comment?
    type == InstantMessage::TYPES[:comment] && !reply?
  end

  def last_comment?
    return false unless root_comment?

    channel.instant_messages.comments.desc(:created_at).first.id == id
  end

  private

  def broadcast_append_to_comments
    if reply?
      broadcast_append_to channel.key,
                          target: "comment_#{parent_message_id}_replies",
                          renderable: Comment::ItemComponent.new(self)
    else
      broadcast_append_to channel.key,
                          target: channel.key,
                          renderable: Comment::ItemComponent.new(self)
    end
  end

  def broadcast_append_to_messages
    broadcast_append_to "channels_messages_#{channel.id}",
                        target: "channels_messages_#{channel.id}",
                        renderable: InstantMessages::ItemComponent.new(self)
  end

  def broadcast_system_message_clear
    broadcast_update_to "system_message_#{channel.id}",
                        target: "system_message_#{channel.id}",
                        html: ''
  end

  def broadcast_replace_system_message
    broadcast_update_to "system_message_#{channel.id}",
                        target: "system_message_#{channel.id}",
                        renderable: InstantMessages::SystemMessageComponent.new(self)
  end

  def suppressed_turbo_broadcasts?
    false
  end
end
