# frozen_string_literal: true

User.class_eval do
  scope :with_emails, ->(email_addresses) { where(:email.in => email_addresses) }

  def display_option
    @display_option ||= SpiritHub::DisplayOption.find_or_create_by(user_id: id)
  end

  def operative_team
    Team.where(:$or => [{ :operators.in => [id.to_s] }, { :writers.in => [id.to_s] }]).first
  end

  def to_be_signed_docs
    Tagset.where(spirit_hubdoc: true, type: 'document', :accounted.in => all_gids_and_user, state_id: SpiritHub::HubdocCycle.find_state_by_key('to_sign')&.id)
  end

  def to_be_signed_for_me_docs
    # TODO
    []
  end

  def to_complete_docs
    Tagset.where(spirit_hubdoc: true, type: 'document', :accounted.in => all_gids_and_user, state_id: SpiritHub::HubdocCycle.find_state_by_key('to_complete')&.id)
  end

  def to_validate_docs
    Tagset.where(spirit_hubdoc: true, type: 'document', :accounted.in => all_gids_and_user, state_id: SpiritHub::HubdocCycle.find_state_by_key('to_validate')&.id)
  end

  def responses_docs
    Tagset.where(spirit_hubdoc: true, type: 'document', :accounted.in => all_gids_and_user, state_id: SpiritHub::HubdocCycle.find_state_by_key('to_answer')&.id)
  end

  def favorite_channel_ids
    Favorite.where(user_id: id, :channel_id.ne => nil).distinct(:channel_id)
  end

  def favorite_channels
    Channel.where(:id.in => favorite_channel_ids)
  end

  def favorite_tagset_ids
    Favorite.where(user_id: id).pluck(:tagset_id).flatten.uniq.compact
  end

  def admin?
    (roles.to_a & %w[Administrator Superadmin]).any?
  end
end
