# frozen_string_literal: true

module SpiritHub
  class DirectoriesPolicy
    attr_reader :user, :directory

    def initialize(user, directory)
      @user = user
      @directory = directory
    end

    def index?
      user.admin? || directory.all_can_access?(user)
    end

    def sort?
      index?
    end

    def add_doc_to_completeness_form?
      user.admin? || directory.all_can_access?(user)
    end

    def add_doc_to_completeness?
      add_doc_to_completeness_form?
    end

    def add_doc_to_tagset_doc_form?
      user.admin? || directory.all_can_access?(user)
    end

    def add_doc_to_tagset_doc?
      add_doc_to_tagset_doc_form?
    end

    def remove?
      user.admin? || directory.writers?(user) || directory.responsible?(user)
    end

    def remove_doc_from_tagset_doc?
      remove?
    end

    def bulk_delete?
      remove?
    end

    def duplicate?
      user.admin? || directory.writers?(user) || directory.responsible?(user)
    end

    class Scope
      attr_reader :user, :scope

      def initialize(user, scope)
        @user = user
        @scope = scope
      end

      def resolve
        return scope.where(spirit_hubdoc: true) if user.admin?

        scope.where(
          spirit_hubdoc: true,
          all_can_access: { :$in => user.all_gids_and_user }
        )
      end
    end
  end
end
