# frozen_string_literal: true

module SpiritHub
  class FavoritesPolicy
    attr_reader :user, :tagset

    def initialize(user, tagset)
      @user = user
      @tagset = tagset
    end

    def index?
      user.present?
    end

    def sort?
      index?
    end

    def remove?
      user.admin? || tagset.writers?(user) || tagset.responsible?(user)
    end

    class Scope
      attr_reader :user, :scope

      def initialize(user, scope)
        @user = user
        @scope = scope
      end

      def resolve
        return scope.where(spirit_hubdoc: true) if user.admin?

        scope.where(
          spirit_hubdoc: true,
          all_can_access: { :$in => user.all_gids_and_user }
        )
      end
    end
  end
end
