# frozen_string_literal: true

module SpiritHub
  class TagsetsPolicy
    attr_reader :user, :tagset

    def initialize(user, tagset)
      @user = user
      @tagset = tagset
    end

    def index?
      user.admin? || tagset.all_can_access?(user)
    end

    def journal_entries?
      user.admin? || tagset.all_can_access?(user)
    end

    def doc?
      user.admin? || tagset.all_can_access?(user)
    end

    def versioning?
      doc?
    end

    def versions?
      doc?
    end

    def detach_version?
      doc?
    end

    def add_doc_form?
      user.present?
    end

    def add_doc?
      add_doc_form?
    end

    def search_directories?
      user.present?
    end

    def add_favorite?
      user.present?
    end

    def remove_favorite?
      add_favorite?
    end

    def form?
      user.present?
    end

    def share?
      SpiritHub::HubdocCycle.can_change_to_state?(tagset, :share, user)
    end

    alias share_from_info_form? share?
    alias share_from_info? share?

    def respond?
      SpiritHub::HubdocCycle.can_change_to_state?(tagset, :respond, user)
    end

    def request_signature?
      SpiritHub::HubdocCycle.can_change_to_state?(tagset, :share, user)
    end

    def classify?
      SpiritHub::HubdocCycle.can_change_to_state?(tagset, :classify, user)
    end

    def evaluate?
      SpiritHub::HubdocCycle.can_change_to_state?(tagset, :evaluate, user)
    end

    def send_to?
      SpiritHub::HubdocCycle.can_change_to_state?(tagset, :sent_to, user)
    end

    def delete_item?
      user.admin? || tagset.writers?(user) || tagset.responsible?(user)
    end

    def bulk_delete?
      delete_item?
    end

    def inline_edit?
      user.admin? || tagset.writers?(user) || tagset.responsible?(user)
    end

    def update_inline?
      inline_edit?
    end

    def split_form?
      user.admin? || tagset.all_can_access?(user)
    end

    def split?
      split_form?
    end

    def office_editable?
      user.admin? || tagset.writers?(user) || tagset.responsible?(user)
    end

    class Scope
      attr_reader :user, :scope

      def initialize(user, scope)
        @user = user
        @scope = scope
      end

      def resolve
        return scope.where(spirit_hubdoc: true) if user.admin?

        scope.where(
          spirit_hubdoc: true,
          all_can_access: { :$in => user.all_gids_and_user }
        )
      end
    end
  end
end
