# frozen_string_literal: true

module SpiritHub
  module Search
    class SpacesSearch < ::Search::SpacesSearch
      def build_in_spaces_filter(query)
        doc_id = query.delete('doc_id')

        query = super(query)

        query['doc_id'] = doc_id if doc_id.present?

        query
      end

      private

      def add_default_filter; end

      def add_nlp_filter
        return if @meaning.nil?
        return if (@vector = Doc.llm_provider&.embed(text: @meaning)&.embedding).nil?

        similar_docs = get_similar_docs(search.pluck(:id))
        @query = { doc_id: { '$in': similar_docs } }
      end

      def get_similar_docs(ids)
        filter = ids.map(&:to_s).then { |mapped_ids| mapped_ids.any? ? "doc_id in #{mapped_ids}" : '' }
        Doc.get_similarities(vector: @vector, limit: 20, filter:).map { |o| o['doc_id'] }
      end
    end
  end
end
