# frozen_string_literal: true

module SpiritHub
  # Sends notification emails when a tagset doc is uploaded
  class TagsetNotifier
    class << self
      def call(*)
        new(*).call
      end
    end

    def initialize(tagset, user)
      @tagset = tagset
      @user = user
    end

    def call
      return unless tagset.doc?

      emails = recursive_ancestor_notifiable_ids(tagset).filter_map do |id|
        parse_id(id)
      end.uniq
      return unless emails.any?

      SpiritHub::TagsetsMailer.document_uploaded(
        tagset_id: tagset.id.to_s,
        emails:
      ).deliver_later
    end

    private

    attr_reader :tagset, :user

    def parse_id(id)
      if id.start_with?('c_')
        Doc.find_by(id: id.split('_').last)&.title
      elsif id.start_with?('u_')
        user = User.find_by(id: id.split('_').last)
        return if user.nil?
        return if user == @user

        user.email
      else
        raise ArgumentError, "Invalid id: #{id}"
      end
    end

    def recursive_ancestor_notifiable_ids(tag)
      (tag.parents.map do |parent|
        recursive_ancestor_notifiable_ids(parent)
      end.flatten + notifiable_ids(tag)).uniq
    end

    def notifiable_ids(tag)
      tag.notifiable_ids || []
    end
  end
end
