# frozen_string_literal: true

module SpiritHub
  # Destroy the doc, purging all references to it.
  class TagsetPurger
    class << self
      def call(*)
        new(*).call
      end

      def clean_linked_models(*)
        new(*).clean_linked_models
      end
    end

    def initialize(tagset, user)
      @tagset = tagset
      @user = user
    end

    def call
      tagset.current_user_id = user.id
      tagset.destroy!

      remove_reference_from_tagsets
      remove_reference_from_completeness
      true
    end

    def clean_linked_models
      remove_reference_from_tagsets
      remove_reference_from_completeness

      true
    end

    private

    attr_reader :tagset, :user

    def remove_reference_from_tagsets
      Tagset.where(tagset_ids: tagset.id.to_s).each { |model| model.tagset_ids.delete(tagset.id.to_s) && model.save! }
    end

    def remove_reference_from_completeness
      SpiritHub::Completeness.where(object_ids: tagset.id).each { |model| model.object_ids.delete(tagset.id) && model.save! }
    end
  end
end
