# frozen_string_literal: true

module SpiritHub
  class TagsetSuggester
    %i[
      suggest_spaces_to_classify
      suggest_validation_comment_on
    ].each do |method_name|
      define_singleton_method(method_name) do |tagset, user, *args, **opts|
        new(tagset, user).public_send(method_name, *args, **opts)
      end
    end

    def initialize(tagset, user)
      @tagset = tagset
      @user = user
    end

    def suggest_spaces_to_classify(limit: 5)
      suggested_spaces = @tagset.docs.to_a.flat_map { |doc| doc.suggests_for('spaces', user: @user, limit:) }
      suggested_spaces.to_a.uniq.take(limit)
    end

    def suggest_validation_comment_on(valdiate_or_refuse)
      return unless valdiate_or_refuse.to_sym.in?(%i[validate refuse])

      similar_docs = @tagset.docs.to_a.flat_map { |doc| doc.suggests_for('docs', user: @user) }.compact
      similar_tagsets = similar_docs.flat_map(&:tagsets).uniq

      code = valdiate_or_refuse.to_sym == :validate ? 'DOC_VALIDATED' : 'DOC_REFUSED'

      tagset_valitation_entries = SpiritHub::JournalEntry.where(code:, :tagset_id.in => similar_tagsets)
      tagset_valitation_entries.pluck(:action_msg).map(&:presence).compact.sample
    end

    def suggest_recipients_to_share_with
      similar_docs = @tagset.docs.to_a.flat_map { |doc| doc.suggests_for('docs', user: @user) }.compact
      similar_tagsets = similar_docs.flat_map(&:tagsets).uniq

      journal_entries = SpiritHub::JournalEntry.where(code: 'DOC_SHARED', :tagset_id.in => similar_tagsets)
      journal_entries.flat_map { |e| e.opts[:to] }.compact.uniq
    end

    def suggest_recipients_to_answer
      similar_docs = @tagset.docs.to_a.flat_map { |doc| doc.suggests_for('docs', user: @user) }.compact
      similar_tagsets = similar_docs.flat_map(&:tagsets).uniq

      journal_entries = SpiritHub::JournalEntry.where(code: 'DOC_SENT_TO_ANSWER', :tagset_id.in => similar_tagsets)
      journal_entries.flat_map { |e| e.opts[:recipients] }.compact.uniq
    end

    def suggest_recipients_to_sign
      similar_docs = @tagset.docs.to_a.flat_map { |doc| doc.suggests_for('docs', user: @user) }.compact
      similar_tagsets = similar_docs.flat_map(&:tagsets).uniq

      journal_entries = SpiritHub::JournalEntry.where(code: 'DOC_SENT_TO_SIGN', :tagset_id.in => similar_tagsets)
      journal_entries.flat_map { |e| e.opts[:recipients] }.compact.uniq
    end

    def suggest_recipients_to_send_to(state_key)
      return suggest_recipients_to_answer if state_key.to_sym == :to_answer

      []
    end
  end
end
