# frozen_string_literal: true

module SpiritHub
  class TagsetVersioner
    class << self
      def call(*)
        new(*).call
      end
    end

    def initialize(tagset, document, user)
      @tagset = tagset
      @document = document
      @user = user
    end

    def versioning_from_new_file(new_file)
      filename = new_file.original_filename
      @document.store_version_from_disk(new_file.tempfile.path, @user, filename)
      @tagset.update!(title: filename)
    end

    def versioning_from_existing_document(existing_doc_id)
      new_current_version = Doc.find_by(id: existing_doc_id)
      return unless new_current_version.present?

      @document.fuse_with(new_current_version)
      @tagset.update!(title: new_current_version.title)
    end
  end
end
