import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
import '../../../support/step_definitions/modal_steps';

Given('There is some directories', () => {
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 1' }]]);
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Searchable tagset 2' }]]);
  cy.appFactories([['create_list', 'tagset_directory', 3, { responsible: '1' }]]);
});

When('I click on the add doc button', () => {
  cy.get('form[action="/spirit_hub/tagsets/add_doc_form"]').submit();
});

When('I add one doc', () => {
  cy.get('input[data-classify-form-target="fileInput"]').attachFile('files/example.pdf');
});

When('I submit the form', () => {
  cy.get('form[action="/spirit_hub/tagsets/add_doc"] button[type="submit"]').click();
  cy.waitForTurboResponse();
});

Then('I should see the doc in the list', () => {
  cy.get('#filter_search_form button:last').click();
  cy.get('#model_table tbody tr:first').contains('example.pdf');
});

Then('I add multiple docs', () => {
  cy.get('input[data-classify-form-target="fileInput"]').attachFile(['files/example.pdf', 'files/example.jpeg']);
});

Then('I add new docs', () => {
  cy.get('input[data-classify-form-target="fileInput"]').attachFile(['files/example.png', 'files/example.docx']);
});

Then('I should see all the docs in the list', () => {
  cy.get('#filter_search_form button:last').click();
  cy.get('#model_table tbody').contains('example.pdf');
  cy.get('#model_table tbody').contains('example.jpeg');
  cy.get('#model_table tbody').contains('example.png');
  cy.get('#model_table tbody').contains('example.docx');
});

Then('I should see the docs in the list', () => {
  cy.get('#filter_search_form button:last').click({ force: true });
  cy.get('#model_table tbody tr:first').contains('example.jpeg');
  cy.get('#model_table tbody tr:eq(1)').contains('example.pdf');
});

When('I regroup the docs', () => {
  cy.get('label[data-classify-form-target="regroupButton"]').click();
});

Then('The doc is a regrouped doc', () => {
  cy.get('#model_table tbody tr:first img[src*="doc_multiple"]').should('exist');
});

Then('I cannot add a action', () => {
  cy.get('input[data-classify-form-target="addAction"]').next('div').should('not.be.visible');
});

Then('I can add a action', () => {
  cy.get('input[data-classify-form-target="addAction"]').next('div').should('be.visible');
});

When('I select the share action', () => {
  cy.get('input[data-classify-form-target="addAction"]').next('div').click();
  cy.get('#next_state_id').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Partager').first().click({ force: true });
});

Then('I should see the share form', () => {
  cy.get('#modal header').contains('Partager');
  cy.get('#modal button[data-action="click->modal#hideModal"]').click();
});

Then('I should not see the share form', () => {
  cy.get('#modal').should('not.contain', 'Partager');
});

When('I cancel the regrouping', () => {
  cy.get('label[data-classify-form-target="regroupButton"]').click();
});

Given('There is one directory with completeness', () => {
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', title: 'Tagset 1' }]]).then(records => {
    const tagset_id = records[0].id;
    cy.appFactories([['create', 'completeness', { title: 'Completeness 1', tagset_id: tagset_id }]]);
  });
});

Then('I select the completeness', () => {
  cy.get('img[alt="Tagset 1"][data-toggle-subrows-target="image"]').click();
  cy.get('label').contains('Completeness 1').click();
});

Then('I should see the completeness in the list', () => {
  cy.get('#filter_search_form button:last').click({ force: true });
  cy.get('#model_table tbody tr:first').contains('Completeness 1');
});
