import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
import '../../../support/step_definitions/modal_steps';

Then('There should not have a chatbot modal', () => {
  cy.get('#chatbot-modal dialog').should('not.exist');
});

When('I click on the chatbot button', () => {
  cy.get('a[data-turbo-frame="chatbot-modal"]').click();
});

Then('I should see the chatbot modal', () => {
  cy.get('#chatbot-modal dialog').should('be.visible');
});

When('I click on the close button', () => {
  cy.get('button[data-action="chatbot-modal#hideDialog"]').click();
});

Then('I should not see the chatbot modal', () => {
  cy.get('#chatbot-modal dialog').should('not.be.visible');
});

When('I click on the backdrop', () => {
  cy.get('#chatbot-modal dialog').click('topLeft');
});

When('I type {string} in the chatbot input', string => {
  cy.get('#channel_text').type(`${string}{enter}`);
});

Given('The bot answers', () => {
  cy.wait(500);
  cy.get('#channel_text')
    .closest('form')
    .invoke('attr', 'action')
    .then(actionUrl => {
      const channel_id = actionUrl.split('/').pop();
      cy.appFactories([['create', 'instant_message', { llm_role: 'bot', channel_id: channel_id, text: 'Bot Response' }]]);
    });
});

Then('I can see the chat in the list', () => {
  cy.get('#chatbot-modal dialog h2').contains("Aujourd'hui").next('div').contains('HubGPT et du ');
});

When('I click on the chat 1 in the chat list', () => {
  cy.get('#chatbot-modal dialog a').contains('Chat 1').click();
});

When('I click on the chat 2 in the chat list', () => {
  cy.get('#chatbot-modal dialog a').contains('Chat 2').click();
});

Then('I should see the chat message {string}', string => {
  cy.get('#chatbot-modal dialog [id^="channels_messages_"]').contains(string);
});

Then('I can see the loading spinner', () => {
  cy.get('#chatbot-modal dialog svg[data-spinner-target="spinner"]').should('be.visible');
});

Then("I don't see the loading spinner", () => {
  cy.get('#chatbot-modal dialog svg[data-spinner-target="spinner"]').should('be.not.visible');
});

When('I add the chat 1 to favorites', () => {
  cy.get('button[data-better-dropdown-target="toggleButton"]').last().click();
  cy.get('a[href="/spirit_hub/channels/channel1/favorite"]:visible').first().click();
});

Then('I should see the chat 1 in the favorites list', () => {
  cy.get('#chatbot-modal dialog h2').contains('Mes favoris').next('div').contains('Chat 1');
  cy.get('#chatbot-modal dialog h2').contains("Aujourd'hui").next('div').should('not.contain', 'Chat 1');
});

When('I remove the chat 1 from favorites', () => {
  cy.get('button[data-better-dropdown-target="toggleButton"]').first().click();
  cy.get('a[href="/spirit_hub/channels/channel1/unfavorite"]:visible').first().click();
});

Then('I should not see the chat 1 in the favorites list', () => {
  cy.get('#chatbot-modal dialog h2').contains('Mes favoris').next('div').should('not.contain', 'Chat 1');
  cy.get('#chatbot-modal dialog h2').contains("Aujourd'hui").next('div').contains('Chat 1');
});

When('I rename the chat 1 to {string}', string => {
  cy.get('#chatbot-modal dialog a').contains('Chat 1').click();
  cy.get('#chatbot-modal dialog a.pointer-events-none span').contains('Chat 1').click();
  cy.get('input[name="channel[name]"]:visible').first().clear().type(`${string}{enter}`);
});

Then('I should see the chat 1 with the name {string}', string => {
  cy.get('#chatbot-modal dialog a').contains(string);
});

When('I delete the chat 1', () => {
  cy.get('button[data-better-dropdown-target="toggleButton"]').last().click();
  cy.get('a:visible').contains('Supprimer').click();
});

Then('I should not see the chat 1 in the chat list', () => {
  cy.get('#chatbot-modal dialog').should('not.contain', 'Chat 1');
});

When('I click on the chat button of the doc', () => {
  cy.get('#model_table tbody tr:first td:last button[data-better-dropdown-target="toggleButton"]:visible').click();
  cy.get('div[data-better-dropdown-target="menu"]:visible a').contains('HubGPT').click();
});
