import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
import '../../../support/step_definitions/modal_steps';

let tagset_ids, directory_id, john_id, jack_id, josh_id;

Given('There is some docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, 'with_state']]);
});

Given('There is a directory with some docs', () => {
  tagset_ids = [];

  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'dog.jpg' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'one_page.pdf' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'pdf_sample.pdf' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'pdf_sample2.pdf' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_file', { filename: 'pdf_sample3.pdf' }]]).then(records => {
    tagset_ids.push(records[0].id);
  });
  cy.appFactories([['create', 'tagset_directory', 'with_journal_entries', { responsible: '1', id: '1', tagset_ids: tagset_ids }]]).then(records => {
    directory_id = records[0].id;
  });
});

Given('There is a tagset with multiple docs', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_state', 'with_files', { filenames: ['pdf_sample.pdf', 'pdf_sample2.pdf'] }]]);
});

Given('There are existing users I want to send the doc to', () => {
  cy.appFactories([['create', 'user', { email: 'john@test.com', first_name: 'John', last_name: 'Doe' }]]).then(records => {
    john_id = records[0].id;
  });
  cy.appFactories([['create', 'user', { email: 'jack@test.com', first_name: 'Jack', last_name: 'Black' }]]).then(records => {
    jack_id = records[0].id;
  });
  cy.appFactories([['create', 'user', { email: 'josh@test.com', first_name: 'Josh', last_name: 'Homme' }]]).then(records => {
    josh_id = records[0].id;
  });
});

Given('There are similar docs that have been answered already', () => {
  cy.appFactories([['create', 'suggest_from_tagset_doc_to_tagset_doc', { from_tagset_doc_id: tagset_ids[0], to_tagset_doc_id: tagset_ids[1] }]]);
  cy.appFactories([['create', 'suggest_from_tagset_doc_to_tagset_doc', { from_tagset_doc_id: tagset_ids[0], to_tagset_doc_id: tagset_ids[2] }]]);

  cy.appFactories([['create', 'journal_entry', { code: 'DOC_SENT_TO_ANSWER', tagset_id: tagset_ids[1], opts: { recipients: [john_id] } }]]);
  cy.appFactories([['create', 'journal_entry', { code: 'DOC_SENT_TO_ANSWER', tagset_id: tagset_ids[2], opts: { recipients: [jack_id, josh_id] } }]]);
});

Given('There are similar docs that have been signed already', () => {
  cy.appFactories([['create', 'suggest_from_tagset_doc_to_tagset_doc', { from_tagset_doc_id: tagset_ids[0], to_tagset_doc_id: tagset_ids[1] }]]);
  cy.appFactories([['create', 'suggest_from_tagset_doc_to_tagset_doc', { from_tagset_doc_id: tagset_ids[0], to_tagset_doc_id: tagset_ids[2] }]]);

  cy.appFactories([['create', 'journal_entry', { code: 'DOC_SENT_TO_SIGN', tagset_id: tagset_ids[1], opts: { recipients: [john_id] } }]]);
  cy.appFactories([['create', 'journal_entry', { code: 'DOC_SENT_TO_SIGN', tagset_id: tagset_ids[2], opts: { recipients: [jack_id, josh_id] } }]]);
});

When('I visit the directory url', () => {
  cy.visit(`/spirit_hub/directories/${directory_id}/index`);
});

When('I click on the send {string} button', action => {
  cy.wait(1000);
  cy.get('#model_table tbody tr:first td:last button[title="Autres actions"]').first().click();
  cy.get('#model_table tbody tr:first td:last button:visible').contains('Envoyer...').click();
  cy.get(`form[action="/spirit_hub/tagsets/form/${action}"]`).first().click();
});

When('I fill the form', () => {
  cy.get('select[name="recipients[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Admin User (admin@test.com)').first().click({ force: true });
  cy.get('textarea[name="message"]').type('This is a message');
});

When('I fill the to sign form', () => {
  cy.get('select[name="doc_ids[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'pdf_sample2.pdf').first().click({ force: true });
  cy.get('select[name="doc_ids[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'pdf_sample.pdf').first().click({ force: true });
  cy.get('select[name="recipients[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Admin User (admin@test.com)').first().click({ force: true });
  cy.get('textarea[name="comments"]').type('This is a message');
});

When('I submit the form', () => {
  cy.get('button[data-base-form-target="submitButton"]').click({ force: true });
  cy.waitForTurboResponse();
});

Then('I can apply the AI suggestion for the recipients', option => {
  cy.get('select[name="recipients[]"]').next('div').find('.ss-value-text:visible').should('not.exist');

  cy.get('a').contains("Suggestion d'IA").click();
  cy.get('select[name="recipients[]"]').next('div').find('.ss-value-text:visible').contains('john@test.com').should('exist');
  cy.get('select[name="recipients[]"]').next('div').find('.ss-value-text:visible').contains('jack@test.com').should('exist');
  cy.get('select[name="recipients[]"]').next('div').find('.ss-value-text:visible').contains('josh@test.com').should('exist');
});

Given('There is a directory with a completeness', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_file', { responsible: '1', title: 'X Doc' }]]).then(records => {
    const tagset_doc_id = records[0].id;
    cy.appFactories([['create', 'tagset_directory', { responsible: '1', tagset_ids: [tagset_doc_id] }]]).then(records => {
      const tagset_id = records[0].id;
      cy.appFactories([['create', 'completeness', { title: 'Completeness 1', tagset_id: tagset_id }]]);
    });
  });
});

Then('The directory as not changed status', () => {
  cy.get('#model_table tbody tr:first').contains('À completer');
});

Then('The directory is in the todos list', () => {
  cy.get('#model_table tbody tr:first').contains('Tagset Title 1');
});

When('I fill the to sign form with one file', () => {
  cy.get('select[name="doc_ids[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'dog.jpg').first().click({ force: true });
  cy.get('select[name="recipients[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Admin User (admin@test.com)').first().click({ force: true });
  cy.get('textarea[name="comments"]').type('This is a message');
});
