import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
import '../../../support/step_definitions/modal_steps';

let directory_id, tagset_id, doc1, doc2, john, joe;

Given('There are some users', () => {
  cy.appFactories([['create', 'user', { email: 'john@test.com', first_name: 'John', last_name: 'Doe' }]]).then(records => {
    john = records[0];
  });
  cy.appFactories([['create', 'user', { email: 'joe@test.com', first_name: 'Joe', last_name: 'Regular' }]]).then(records => {
    joe = records[0];
  });
});

Given('There is a directory with a doc with email addresses that have been extracted from its content', () => {
  cy.appFactories([['create', 'pdf_doc', { title: 'Doc 1', extracted_emails: [john.email, joe.email], extracted_emails_at: new Date().toString() }]]).then(docs1 => {
    doc1 = docs1[0];

    cy.appFactories([['create', 'pdf_doc', { title: 'Doc 2', extracted_emails: ['new_contact@gmail.com'], extracted_emails_at: new Date().toString() }]]).then(docs2 => {
      doc2 = docs2[0];

      cy.appFactories([['create', 'tagset_doc', 'with_state', { doc_ids: [doc1.id, doc2.id] }]]).then(tagsets => {
        tagset_id = tagsets[0].id;

        cy.appFactories([['create', 'tagset_directory', 'with_journal_entries', { responsible: '1', id: '1', tagset_ids: [tagset_id] }]]).then(dirs => {
          directory_id = dirs[0].id;
        });
      });
    });
  });
});

When('I visit the directory url', () => {
  cy.visit(`/spirit_hub/directories/${directory_id}/index`);
});

Then('I can share that doc based on the extracted emails', option => {
  cy.get('#model_table tbody tr:first td:last div[data-controller="better-dropdown"] button').first().click();
  cy.get(`form[action*="/spirit_hub/tagsets/${tagset_id}/share_from_info_form"] button[type="submit"]`).first().click();

  cy.get('legend').contains(doc1.title).should('exist');
  cy.get('legend').contains(doc2.title).should('exist');

  cy.get(`select[name="docs[${doc1.id}][to][]"]`).next('div').find('.ss-value-text:visible').contains(john.email).should('exist');
  cy.get(`select[name="docs[${doc1.id}][to][]"]`).next('div').find('.ss-value-text:visible').contains(joe.email).should('exist');
  cy.get(`select[name="docs[${doc2.id}][to][]"]`).next('div').find('.ss-value-text:visible').contains('new_contact@gmail.com').should('exist');

  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"] button[type="submit"]').first().click();

  cy.get('#flash_messages').find('div').contains('Document partagé').should('exist');
});