import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
import './doc_view';
import '../modals/send_to_modal';

Given('There is a doc with a comment', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_file', { id: '1', responsible: '1' }]]).then(records => {
    cy.appFactories([
      ['create', 'channel', {
        id: '1',
        tagset_id: records[0].id,
        responsible: '1',
        key: 'tagset_comments_1',
        name: 'Tagset Doc 1 Comment'
      }]
    ]).then(records => {
      cy.appFactories([
        ['create', 'comment', {
          channel_id: records[0].id,
          text: 'Hello world',
          user_id: '1'
        }]
      ]);
    });
  });
});

When('I click on the comment button', () => {
  cy.get('button').contains('Commentaires').click();
});

When('I add a comment {string}', (content) => {
  cy.get('#modal textarea[name="comment[content]"]').type(content);
  cy.get('#modal form[action*="/comments"]').submit();
});

When('I click reply on the first comment', () => {
  cy.get('#modal .comment').first().find('button').contains('Répondre').click();
});

When('I add a reply {string}', (content) => {
  cy.get('#modal .comment form textarea[name="comment[content]"]').type(content);
  cy.get('#modal .comment form[action*="/comments"]').submit();
});

Then('I should see the comment {string}', (content) => {
  cy.get('#modal .comment').contains(content);
});

Then('I should see my name as the comment author', () => {
  cy.get('#modal .comment').first().find('.comment-author').contains('Admin User');
});

Then('I should see the reply {string} under the first comment', (content) => {
  cy.get('#modal .comment').first().find('.comment-replies').contains(content);
});

Then('I should see my name as the reply author', () => {
  cy.get('#modal .comment').first().find('.comment-replies .comment-author').contains('Admin User');
});

When('I fill the share form', () => {
  cy.get('select[name="to[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Admin User (admin@test.com)').first().click({ force: true });

  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
});

When('I visit the latest share', () => {
  cy.visit('/spirit_hub/shares/1');
});

When('I open the sharing link', () => {
  cy.get('.journal_entry')
    .contains('Lien de partage:')
    .invoke('text')
    .then((text) => {
      const urlRegex = /http[s]?:\/\/[^\s]+/;
      const [url] = text.match(urlRegex) || [];
      if (url) {
        const relativePath = new URL(url).pathname;
        cy.visit(relativePath);
      } else {
        throw new Error('No URL found in the text');
      }
    });
});
