import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';
import '../../../support/step_definitions/doc_view_steps';

let tagset_id;
let doc_id;

Given('There is one favorite doc', () => {
  cy.appFactories([['create', 'doc_favorite', 'with_file', { user_id: '1' }]]).then(records => {
    tagset_id = records[0].tagset_id;
  });
});

Given('There is one doc', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_file', 'with_state', { filename: 'pdf_sample.pdf', state_key: 'to_validate' }]]).then(records => {
    doc_id = records[0].doc_ids[0];
    tagset_id = records[0].id;
  });
});

Given('There is one wopi editable doc', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_file', 'with_state', { filename: 'doc_sample.docx', state_key: 'to_validate' }]]).then(records => {
    doc_id = records[0].doc_ids[0];
    tagset_id = records[0].id;
  });
});

When('I click on the first doc', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
});

When('I visit the doc page', () => {
  cy.visit(`/spirit_hub/tagsets/${tagset_id}/doc/${doc_id}`);
  cy.wait(1000); // TODO: remove when have a proper pdf viewer loading state
});

When('I validate the doc', () => {
  cy.get('form[action="/spirit_hub/tagsets/form/validate"] button').click();
  cy.get('textarea[name="message"]').type('This is a message');
  cy.get('select[name="recipients[]"]').next('div').click();
  cy.contains('.ss-list:visible > .ss-option', 'Admin User (admin@test.com)').first().click({ force: true });
  cy.get('button[data-base-form-target="submitButton"]').click({ force: true });
  cy.waitForTurboResponse();
});

Then('There is no more validation button', () => {
  cy.get('form[action="/spirit_hub/tagsets/form/validate"]').should('not.exist');
});

Then('I can toggle the button actions', () => {
  cy.get('button[title="Actions"]').click();
});

Then('I can click on the sent to button', () => {
  cy.get('button:visible').contains('Envoyer...').click();
});

When('I click on the share button', () => {
  cy.get('form[action*="/share"] button:visible').click();
});

Then('I can not edit with Office Online', () => {
  cy.contains('Éditer dans Office Online').should('not.exist');
});

Then('I can edit with Office Online', () => {
  cy.contains('Éditer dans Office Online').should('exist');
});

Then('The preview should be visible', () => {
  cy.get('canvas[data-pdf-viewer-target="content"]').should('be.visible');
});

When('Doc get a new file', () => {
  cy.appEval(`
    d = Doc.find('${doc_id}')
    d.store_file_from_disk(Rails.root.join('packages/spirit_hub/spec/fixtures/files/one_page.pdf'))
  `);
});

Then('The preview should have {string} pages', pages => {
  cy.get('[data-pdf-viewer-target="thumbnailContainer"]').find('.thumbnail').should('have.length', parseInt(pages));
});

When('I activate the annotation mode', () => {
  cy.get('button[data-pdf-viewer-target="editButton"]').click();
});

When('I add a text annotation {string} at {string}, {string}', (content, x, y) => {
  cy.intercept('POST', '/spirit_hub/documents/*/pdf_annotations').as('pdfAnnotation');

  cy.get('div[data-pdf-viewer-target="annotationLayer"]').click(parseInt(x), parseInt(y));
  cy.get('div[data-pdf-annotation-target="input"]').type(`${content}{enter}`);

  cy.wait('@pdfAnnotation').its('response.statusCode').should('eq', 201);
});

When('I should see the annotation {string} around {string}, {string}', (content, x, y) => {
  cy.get('div[data-pdf-viewer-target="annotationLayer"]')
    .contains(content)
    .then($annotation => {
      const position = $annotation.parent().position();
      const expectedX = parseInt(x);
      const expectedY = parseInt(y);
      const tolerance = 10;

      expect(position.left).to.be.closeTo(expectedX, tolerance);
      expect(position.top).to.be.closeTo(expectedY, tolerance);
    });
});

Then('I can remove the annotation {string}', content => {
  cy.intercept('DELETE', '/spirit_hub/documents/*/pdf_annotations/*').as('pdfAnnotationDelete');

  cy.get('div[data-pdf-viewer-target="annotationLayer"]').contains(content).parent().find('button[data-pdf-annotation-target="deleteButton"]').click({ force: true });

  cy.wait('@pdfAnnotationDelete').its('response.statusCode').should('eq', 204);
});

Then('I should not see the annotation {string}', content => {
  cy.get('div[data-pdf-viewer-target="annotationLayer"]').should('not.contain', content);
});

When('I move the annotation {string} to {string}, {string}', (content, x, y) => {
  const offsetX = parseInt(x);
  const offsetY = parseInt(y);

  cy.intercept('PATCH', '/spirit_hub/documents/*/pdf_annotations/*').as('pdfAnnotationUpdate');

  cy.get('div[data-pdf-viewer-target="annotationLayer"]').then($layer => {
    const layerRect = $layer[0].getBoundingClientRect();

    cy.get('div[data-pdf-viewer-target="annotationLayer"]')
      .contains(content)
      .parent()
      .then($annotation => {
        const annotationRect = $annotation[0].getBoundingClientRect();
        const clientX = layerRect.left + offsetX;
        const clientY = layerRect.top + offsetY;

        cy.wrap($annotation)
          .trigger('mousedown', { which: 1, clientX: annotationRect.left, clientY: annotationRect.top })
          .trigger('mousemove', { clientX, clientY })
          .trigger('mouseup', { force: true });
        cy.wait('@pdfAnnotationUpdate').its('response.statusCode').should('eq', 200);
      });
  });
});

When('I edit the annotation {string} to {string}', (content, newContent) => {
  cy.intercept('PATCH', '/spirit_hub/documents/*/pdf_annotations/*').as('pdfAnnotationUpdate');

  cy.get('div[data-pdf-viewer-target="annotationLayer"]').contains(content).dblclick().type(`{selectall}${newContent}{enter}`);

  cy.wait('@pdfAnnotationUpdate').its('response.statusCode').should('eq', 200);
});
