import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Given('There is one tagset todo with all columns', () => {
  cy.appFactories([['create', 'operation', { id: 'operation1', title: 'Operation 1' }]]);
  cy.appFactories([
    ['create', 'tagset_doc', 'with_informed', 'with_file', { responsible: '1', parent_tagset_ids: ['a'], percent: 20, operation_id: 'operation1', accounted: ['1'] }],
  ]);
});

Then('I should see the right columns', () => {
  cy.get('#model_table td').eq(3).contains('Doc Title 1');
  cy.get('#model_table td').eq(4).contains('Operation 1');
  cy.get('#model_table td').eq(5).contains('7.1 Ko');
  cy.get('#model_table td').eq(6).contains(new Date().toLocaleDateString('fr-FR'));
  cy.get('#model_table td').eq(7).find('div').should('exist');
  cy.get('#model_table td').eq(8).find('img').should('exist');
  cy.get('#model_table td').eq(9).contains('À classer');
  cy.get('#model_table td').eq(10).find('a').should('exist');
});

Given('There is some todos docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', parent_tagset_ids: ['a'], percent: 20, accounted: ['1'] }]]);
});

Given('There is a lot of todos docs', () => {
  cy.appFactories([['create_list', 'tagset_doc', 20, { responsible: '1', parent_tagset_ids: ['a'], percent: 20, accounted: ['1'] }]]);
});

Given('There is some todos docs and some directories', () => {
  cy.appFactories([['create_list', 'tagset_doc', 5, { responsible: '1', parent_tagset_ids: ['a'], percent: 20, accounted: ['1'] }]]);
  cy.appFactories([['create_list', 'tagset_directory', 10, { responsible: '1' }]]);
});

// Add doc
Then('I should not see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 5);
});

Then('I should see the doc in the list', () => {
  cy.get('#model_table tbody tr:visible').should('have.length', 6);
});

When('I click on the last created doc', () => {
  cy.get('#model_table tbody tr:first td:last a:first').click();
});

Then('I should see the history journal entries', () => {
  cy.get('button#history-journal-entries').click();
});

Given('There is a doc to validate on my todos page', () => {
  cy.appFactories([['create', 'tagset_doc', 'with_state', { state_key: 'to_validate', accounted: ['1'], percent: 20, responsible: '1', parent_tagset_ids: ['a'] }]]);
});

Then('I can see user selected by default', () => {
  cy.get('#model_table tbody tr:first form[action="/spirit_hub/tagsets/form/validate"] button').click();
  cy.get('select[name="recipients[]"]').contains('Admin User (admin@test.com)');
});

Then('I can validate the doc', () => {
  cy.get('textarea[name="message"]').type('This is a message');
  cy.get('button[data-base-form-target="submitButton"]').click({ force: true });
  cy.waitForTurboResponse();
  cy.get('#model_table tbody tr:first').contains('Validé');
});

Given('There is a doc i can respond on my todos page', () => {
  cy.appFactories([['create', 'tagset_doc', { accounted: ['1'], percent: 20, responsible: '1', parent_tagset_ids: ['a'] }]]);
});

Then('I can share and and not see it in the list', () => {
  cy.get('#model_table tbody tr:first form').filter('[action="/spirit_hub/tagsets/form/share"]').first().submit();
  cy.get('select[name="to[]"]').next('div').click();
  cy.get('.ss-list > div:visible').first().click({ force: true });
  cy.get('input[name="subject"]').first().type('Hey');
  cy.get('textarea[name="message"]').first().type('Hello there!');
  cy.get('form[action*="/share"]').first().submit();
  cy.waitForTurboResponse();
  cy.get('#model_table tbody tr:visible').should('have.length', 4);
});

Then('I can classify and and not see it in the list', () => {
  cy.get('#model_table tbody tr:first td:last div[data-controller="better-dropdown"] button').first().click();
  cy.get('#model_table tbody tr:first td:last div[data-better-dropdown-target="menu"]').contains('Classer').click();
  cy.get('#directory_selector label').first().click();
  cy.get('button[data-classify-form-target="submitButton"]').click();
  cy.waitForTurboResponse();
  cy.get('#model_table tbody tr:visible').should('have.length', 4);
});

Then('I can make tagset done and not see it in the list', () => {
  cy.get('#model_table tbody tr:first td:last div[data-controller="better-dropdown"] button').first().click();
  cy.get('#model_table tbody tr:first td:last div[data-better-dropdown-target="menu"]').contains('Fin de traitement').click();
  cy.waitForTurboResponse();
  cy.get('#model_table tbody tr:visible').should('have.length', 4);
});

Given('The is a directories in the todos', () => {
  cy.appFactories([['create', 'tagset_directory', { responsible: '1', accounted: ['1'], parent_tagset_ids: ['a'] }]]);
});

When('I click on the done button', () => {
  cy.get('#model_table tbody tr:first td:last div[data-controller="better-dropdown"] button').first().click();
  cy.get('#model_table tbody tr:first td:last div[data-better-dropdown-target="menu"]').contains('Fin de traitement').click();
});

Then("I don't see the directory anymore", () => {
  cy.get('#model_table tbody').should('not.contain', 'Tagset Title 1');
});
