import { Given, When, Then } from '@badeball/cypress-cucumber-preprocessor';

Then('I can download the document', () => {
  cy.intercept('GET', '**/download/*').as('fileDownload');
  cy.intercept('GET', '**/documents/*/upload?mode=attachment').as('fileDownload');

  cy.get('a[download=true]').first().click();

  cy.wait('@fileDownload').then(interception => {
    expect(interception.response.statusCode).to.eq(200);
  });
});

Then('I am on page {string}', page => {
  cy.get('input[data-pdf-viewer-target="indexIndicator"]').should('have.value', page);
  cy.get('div[data-pdf-viewer-target="thumbnailContainer"] .thumbnail')
    .eq(page - 1)
    .should('have.class', 'border-spirit-red');
  if (page === '1') {
    cy.get('button[data-action="click->pdf-viewer#previousPage"]').should('be.disabled');
  }
  if (page === '5') {
    cy.get('button[data-action="click->pdf-viewer#nextPage"]').should('be.disabled');
  }
});

When('I click on the 3rd page in the mini pages', () => {
  cy.get('div[data-pdf-viewer-target="thumbnailContainer"] .thumbnail').eq(2).click();
});

When('I click on the last page in the mini pages', () => {
  cy.get('div[data-pdf-viewer-target="thumbnailContainer"] .thumbnail').eq(4).click();
});

When('I click on the previous page 4 times', () => {
  for (let i = 0; i < 4; i++) {
    cy.get('button[data-action="click->pdf-viewer#previousPage"]').click();
  }
});

When('I click on the next page', () => {
  cy.get('button[data-action="click->pdf-viewer#nextPage"]').click();
});

When('I change the input to 4', () => {
  cy.get('input[data-pdf-viewer-target="indexIndicator"]').clear().type('4{enter}');
});

When('I zoom in', () => {
  cy.get('button[data-action="click->pdf-viewer#zoomIn"]').click();
});

When('I zoom out', () => {
  cy.get('button[data-action="click->pdf-viewer#zoomOut"]').click();
});

Then('The zoom level should be {string}', value => {
  cy.get('span[data-pdf-viewer-target="zoomIndicator"]').should('have.text', `${value}%`);
});

When('I max zoom in', () => {
  for (let i = 0; i < 15; i++) {
    cy.get('button[data-action="click->pdf-viewer#zoomIn"]').click({ force: true });
  }
});

When('I max zoom out', () => {
  for (let i = 0; i < 20; i++) {
    cy.get('button[data-action="click->pdf-viewer#zoomOut"]').click({ force: true });
  }
});
