# frozen_string_literal: true

require 'rails_helper'

describe Tagsets::ShareFromInfoModalComponent, type: :component do
  let(:component) { described_class.new(tagset:) }
  let(:tagset) { create(:tagset_doc, responsible: current_user.id) }
  let(:current_user) { create(:user) }

  describe '#recipients_dropdown_data' do
    subject { component.recipients_dropdown_data }

    context 'when tagset docs contain extracted emails' do
      let(:doc1) { create(:doc, extracted_emails: [users[1].email, users[8].email, contact.email, new_contact_email]) }
      let(:doc2) { create(:doc, extracted_emails: []) }

      let(:users) { [current_user] + create_list(:user, 9) }
      let(:contact) { create(:contact) }
      let(:new_contact_email) { Faker::Internet.email }

      before { tagset.update!(doc_ids: [doc1.id, doc2.id]) }

      it 'loads the options and preselections per doc correctly' do
        expect(subject.dig(doc1.id.to_s, :options)).to match_array(
          [
            [anything, users[0].id.to_s],
            [anything, users[1].id.to_s], # selected
            [anything, users[2].id.to_s],
            [anything, users[3].id.to_s],
            [anything, users[4].id.to_s], # < ---- first 5 user candidates
            [anything, users[8].id.to_s], # selected
            [anything, "c_#{contact.id}"], # selected
            [new_contact_email, new_contact_email] # selected
          ]
        )

        expect(subject.dig(doc1.id.to_s, :preselections)).to match_array(
          [
            users[1].id.to_s,
            users[8].id.to_s,
            "c_#{contact.id}",
            new_contact_email
          ]
        )

        expect(subject.dig(doc2.id.to_s, :options)).to match_array(
          [
            [anything, users[0].id.to_s],
            [anything, users[1].id.to_s],
            [anything, users[2].id.to_s],
            [anything, users[3].id.to_s],
            [anything, users[4].id.to_s],
            [anything, "c_#{contact.id}"]
          ]
        )

        expect(subject.dig(doc2.id.to_s, :preselections)).to eq []
      end
    end
  end
end
