# frozen_string_literal: true

require 'rails_helper'

RSpec.describe(SpiritHub::TagsetsMailer, type: :mailer) do
  describe '#document_uploaded' do
    let(:operation) { create(:operation, title: 'Comptable') }
    let(:directory) { create(:tagset_directory, title: 'Factures', operation:) }
    let(:tagset) { create(:tagset_doc, parent_tagset_ids: [directory.id], title: 'Facture 123', operation:) }
    let(:emails) { ['test@domain.com'] }
    let(:uploader) { create(:user) }
    let(:mail) { SpiritHub::TagsetsMailer.document_uploaded(tagset_id: tagset.id, uploader_user_id: uploader.id, emails:) }

    context 'when the tagset is a document' do
      it 'renders the headers' do
        expect(mail.subject).to eq('Un nouveau document (Facture 123) a été déposé dans le dossier Factures')
        expect(mail.to).to eq(emails)
      end

      it 'renders the body' do
        expect(mail.body.encoded).to include("<p>Un nouveau document vient d'être déposé dans le dossier <b>Factures</b> du projet <b>Comptable</b>.</p>")
        expect(mail.body.encoded).to include(uploader.full_name)
      end
    end

    context 'when the tagset is not a document' do
      let(:tagset) { create(:tagset_directory, operation:) }

      it 'raises an error' do
        expect { mail.body }.to raise_error(ArgumentError, "Tagset with id #{tagset.id} is not a document")
      end
    end
  end
end
