# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::LLM::Tools::OperationsTool, type: :model do
  let(:tool) do
    tool = described_class.new
    tool.user = user
    tool
  end

  let(:user) { create(:user, :confirmed) }

  describe '#get_results' do
    subject { tool.get_results(**properties) }

    let(:properties) { {} }
    let!(:operation1) { create(:operation, code: 'OP1', title: 'ALFA') }
    let!(:operation2) { create(:operation, code: 'OP2', title: 'BETA') }

    it 'returns no results when properties missing' do
      expect(JSON.parse(subject)).to eq []
    end

    context 'when filtering by code' do
      let(:properties) { { 'code' => 'OP1' } }

      it 'returns the correct results' do
        expect(JSON.parse(subject).length).to eq 1
        expect(JSON.parse(subject).first['_id']).to eq operation1.id.to_s
      end
    end

    context 'when filtering by title' do
      let(:properties) { { 'title' => 'BETA' } }

      it 'returns the correct results' do
        expect(JSON.parse(subject).length).to eq 1
        expect(JSON.parse(subject).first['_id']).to eq operation2.id.to_s
      end
    end

    context 'when filtering by code and title' do
      let(:properties) { { 'code' => 'OP1', 'title' => 'BETA' } }

      it 'returns the correct results' do
        expect(JSON.parse(subject)).to eq []
      end
    end
  end
end
