# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::LLM::Tools::WorkflowTool, type: :model do
  let(:tool) do
    tool = described_class.new
    tool.user = user
    tool
  end

  before { SpiritHub::HubdocCycle.import_cycle_from_json }

  let(:user) { create(:user, :confirmed) }

  describe '#get_dashboard_docs' do
    subject { tool.get_dashboard_docs }

    let!(:doc) { create(:doc, responsible: user.id) }
    let!(:space) { create(:tagset_doc, doc_ids: [doc.id], responsible: user.id) }

    it 'returns results' do
      expect(space.type).to eq 'document'
      expect(JSON.parse(subject)['to_classify']).not_to be_empty
    end
  end

  describe '#get_dashboard_docs with to classify' do
    subject { tool.get_dashboard_docs(category: 'to_classify') }

    let!(:doc) { create(:doc, responsible: user.id) }
    let!(:space) { create(:tagset_doc, doc_ids: [doc.id], responsible: user.id) }
    let(:search) { SpiritHub::Search::SpacesSearch.new(Tagset.to_classify.selector, { user: }) }

    it 'returns results' do
      expect(JSON.parse(subject)['to_classify']).not_to be_empty
      expect(search.json_serialized_array).not_to be_empty
    end
  end
end
