# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::Pdf::Annotation::Text, type: :model do
  let(:doc) { create(:doc) }

  describe 'validations' do
    it 'validates presence of content' do
      annotation = described_class.new(page_index: 1, position_data: { 'rect' => [0, 0, 100, 100] })
      annotation.doc = doc
      expect(annotation).not_to be_valid
      expect(annotation.errors[:content]).not_to be_empty
    end
  end

  describe '#annotation_type' do
    it "returns 'freetext'" do
      annotation = described_class.new(page_index: 1, content: 'Some text', position_data: { 'rect' => [0, 0, 100, 100] })
      annotation.doc = doc
      expect(annotation.annotation_type).to eq('freetext')
    end
  end

  describe '#to_frontend_json' do
    it 'merges style data into the frontend JSON' do
      annotation = described_class.new(
        page_index: 2,
        content: 'Hello',
        position_data: { 'rect' => [10, 10, 50, 50] },
        style_data: { 'fontSize' => 12, 'color' => 'red' }
      )
      annotation.doc = doc
      annotation.save!

      frontend_json = annotation.to_frontend_json
      expect(frontend_json).to eq({
                                    id: annotation.id.to_s,
                                    pageIndex: 2,
                                    rect: [10, 10, 50, 50],
                                    value: 'Hello',
                                    annotationType: 'freetext',
                                    fontSize: 12,
                                    color: 'red'
                                  })
    end
  end
end
