# frozen_string_literal: true

require 'rails_helper'

RSpec.describe(SpiritHub::Setting, type: :model) do
  let!(:setting) { described_class.new }

  before { described_class.clear_cache! }

  describe '#cached_value' do
    let(:cache) { double('Cache') }

    before do
      allow(Rails).to receive(:cache).and_return(cache)
      allow(described_class).to receive(:new).and_return(setting)
    end

    context 'when the value does not exists' do
      before { allow(cache).to receive(:fetch).and_return(nil) }

      it 'returns nil' do
        expect(described_class.cached_value(:test_key)).to be_nil
        expect(cache).to have_received(:fetch).with(described_class.cache_key(:test_key))
      end
    end

    context 'when the value exists' do
      before { allow(cache).to receive(:fetch).and_return('test_value') }

      it 'returns the value from cache' do
        expect(described_class.cached_value(:test_key)).to eq('test_value')
        expect(cache).to have_received(:fetch).with(described_class.cache_key(:test_key))
      end
    end
  end

  describe '#main_object_name' do
    context 'when default value' do
      it { expect(described_class.main_object_name).to eq('Projet') }
    end

    context 'when overridden' do
      before do
        setting.object_name = 'Overridden'
        setting.save
      end

      after { described_class.clear_cache! }

      it { expect(described_class.main_object_name).to eq('Overridden') }
    end
  end
end
