# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::DisplayOptionPolicy do
  let(:user) { create(:user) }
  let(:other_user) { create(:user) }
  let(:display_option) { user.display_option }

  subject { described_class }

  permissions :update_shown_columns?, :update_view_type? do
    it 'permits user' do
      expect(subject).to permit(user, display_option)
    end

    it 'denies other users' do
      expect(subject).not_to permit(other_user, display_option)
    end
  end

  describe SpiritHub::DisplayOptionPolicy::Scope do
    let(:scope) { SpiritHub::DisplayOption.all }

    subject { described_class.new(user, scope) }

    it 'only return user display option' do
      expect(subject.resolve).to eq([display_option])
    end

    context 'when other user' do
      let(:user) { other_user }

      it 'only return nothing' do
        expect(subject.resolve).to eq([])
      end
    end
  end
end
