# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::PhasePolicy do
  let(:admin) { create(:user, roles: ['Administrator']) }
  let(:responsible) { create(:user) }
  let(:reader) { create(:user) }
  let(:writer) { create(:user) }
  let(:other_user) { create(:user) }
  let(:operation) { create(:operation, responsible: responsible.id, readers: [reader.id], writers: [writer.id, responsible.id]) }
  let(:phase) { create(:phase, operation:) }

  subject { described_class }

  permissions :inline_edit?, :update_inline? do
    it 'permits admins' do
      expect(subject).to permit(admin, phase)
    end

    it 'permits writers of the operation' do
      [responsible, writer].each do |user|
        expect(subject).to permit(user, phase)
      end
    end

    it 'denies access to other users' do
      [reader, other_user].each do |user|
        expect(subject).not_to permit(user, phase)
      end
    end
  end
end
