# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::SettingPolicy do
  subject { described_class }

  permissions :index?, :inline_edit?, :update_inline? do
    context 'when the user is an admin' do
      let(:user) { create(:user, roles: ['Administrator']) }

      it { expect(subject).to permit(user) }
    end

    context 'when the user is not an admin' do
      let(:user) { create(:user) }

      it { expect(subject).not_to permit(user) }
    end
  end

  describe SpiritHub::SettingPolicy::Scope do
    let!(:setting) { SpiritHub::Setting.new.instance_variable_get(:@settings) }
    let!(:scope) { ::Setting.all }

    subject { described_class.new(user, scope).resolve }

    context 'when the user is an admin' do
      let(:user) { create(:user, roles: ['Administrator']) }

      it { expect(subject).to match_array([setting]) }
    end

    context 'when the user is not an admin' do
      let(:user) { create(:user) }

      it { expect(subject).to be_empty }
    end
  end
end
