# frozen_string_literal: true

require 'rails_helper'

RSpec.describe SpiritHub::TagsetsGroupSuggester, type: :service do
  let(:suggester) { described_class.new(tagsets, user) }

  let(:tagsets) { create_list(:tagset_doc, 2) }
  let(:tagset1) { tagsets.first }
  let(:tagset2) { tagsets.second }
  let(:user) { create(:user) }

  describe '#suggest_spaces_to_classify' do
    subject { suggester.suggest_spaces_to_classify(limit: 3) }

    let(:tagset1_suggestions) { [] }
    let(:tagset2_suggestions) { [] }

    before do
      allow(SpiritHub::TagsetSuggester).to receive(:suggest_spaces_to_classify).with(tagset1, user, limit: 100).and_return(tagset1_suggestions)
      allow(SpiritHub::TagsetSuggester).to receive(:suggest_spaces_to_classify).with(tagset2, user, limit: 100).and_return(tagset2_suggestions)
    end

    it 'returns an empty array when nothing to suggest' do
      expect(subject).to eq []
    end

    context 'when there are space suggestions to the passed tagsets' do
      let(:tagset1_suggestions) { create_list(:tagset_directory, 1) }
      let(:tagset2_suggestions) { create_list(:tagset_directory, 2) }

      it 'returns an empty array, since there are no overlap between them' do
        expect(subject).to eq []
      end
    end

    context 'when there are space suggestions to the passed tagsets, with overlaps' do
      let(:tagset1_suggestions) { [dirs[0], dirs[1], dirs[2]] }
      let(:tagset2_suggestions) { [dirs[0], dirs[2], dirs[3]] }

      let(:dirs) { create_list(:tagset_directory, 4) }

      it 'returns only the ones that are common' do
        expect(subject).to match_array [dirs[0], dirs[2]]
      end
    end

    context 'when there are space suggestions to the passed tagsets, with overlaps, above the limit' do
      let(:tagset1_suggestions) { [dirs[0], dirs[1], dirs[2], dirs[3], dirs[4]] }
      let(:tagset2_suggestions) { [dirs[1], dirs[2], dirs[3], dirs[4], dirs[5]] }

      let(:dirs) { create_list(:tagset_directory, 6) }

      it 'returns only the ones that are common, but within the limit' do
        expect(subject).to match_array [dirs[1], dirs[2], dirs[3]]
      end
    end
  end
end
